@@ -219,12 +219,40 @@ class BaseRequest(object):
         self.setup(**kw)
 
     def set_response(self, **kw):
-        """Store one or several keyword values to be rendered in the response.
-        
-        Raise an exception if the action responded using an unknown keyword.
+        """Set (some part of) the response to be sent when the action request
+        finishes.  Allowed keywords are:
 
-        See :ref:`set_response`.
+        - ``message`` -- a string with a message to be shown to the user.
 
+        - ``alert`` -- True to specify that the message is rather important
+          and should alert and should be presented in a dialog box to be
+          confirmed by the user.
+
+        - ``success``
+        - ``errors``
+        - ``html``
+        - ``rows``
+        - ``data_record``
+        - ``goto_record_id``
+        - ``refresh``
+        - ``refresh_all``
+        - ``close_window``
+        - ``xcallback``
+        - ``open_url``
+        - ``open_davlink_url``
+        - ``info_message``
+        - ``warning_message``
+        - ``eval_js``
+
+        This does not yet respond anything, it is stored until the action
+        has finished. The response might be overwritten by subsequent
+        calls to :meth:`set_response`.
+
+        :js:func:`Lino.handle_action_result` will get these instructions
+        as *keywords* and thus will not know the order in which they have
+        been issued. This is a design decision.  We *want* that, when
+        writing custom actions, the order of these instructions does not
+        matter.
 
         """
         for k in kw.keys():
@@ -320,6 +348,27 @@ class BaseRequest(object):
         return settings.SITE.ui.add_callback(self, *args, **kw)
 
     def goto_instance(self, obj, **kw):
+        """
+        Ask the client to display a :term:`detail window` on the given
+        record. The client might ignore this if Lino does not know a
+        detail window.
+
+        This is a utility wrapper around :meth:`set_response` which sets
+        either `data_record` or a `record_id`.
+
+        Usually `data_record`, except if it is a `file upload
+        <https://docs.djangoproject.com/en/dev/topics/http/file-uploads/>`_
+        where some mysterious decoding problems (:blogref:`20120209`)
+        force us to return a `record_id` which has the same visible
+        result but using an additional GET.
+
+        If the calling window is a detail on the same table, then it
+        should simply get updated to the given record. Otherwise open a
+        new detail window.
+
+
+
+        """
         js = self.instance_handler(obj)
         kw.update(eval_js=js)
         self.set_response(**kw)
@@ -771,6 +820,7 @@ class ActorRequest(BaseRequest):
         return self.bound_action.action.render_to_dict(self)
 
     def goto_instance(self, obj, **kw):
+        "See :meth:`BaseRequest.goto_instance`"
         # e.g. find_by_beid is called from viewport, so there is no
         # requesting_panel.
         if self.actor.model is None \
@@ -778,10 +828,11 @@ class ActorRequest(BaseRequest):
            or self.actor.detail_action is None:
            # or self.requesting_panel is None:
             return super(ActorRequest, self).goto_instance(obj, **kw)
-        detail_action = obj.get_detail_action(self)
-        # self.set_response(actor_url=self.actor.actor_url())
+        da = obj.get_detail_action(self)
+        if da is None:
+            return
         self.set_response(
-            detail_handler_name=detail_action.full_name())
+            detail_handler_name=da.full_name())
         if self.actor.handle_uploaded_files is not None:
             self.set_response(record_id=obj.pk)
         else:
