@@ -2,9 +2,10 @@
 .. toctree::
 
 .. autosummary::
-   :toctree: _management
+   :toctree:
 
     diag
+    initdb
     initdb_demo
     makedocs
     makescreenshots
