@@ -1,9 +1,7 @@
 # Copyright 2009-2014 by Luc Saffre.
 # License: BSD, see LICENSE for more details.
 
-"""
-
-.. management_command:: initdb
+""".. management_command:: initdb
 
 Performs an initialization of the database, replacing all data by default
 data (according to the specified fixtures).
@@ -12,19 +10,25 @@ This command REMOVES *all existing tables* from the database
 (not only Django tables), then runs Django's `syncdb`
 and `loaddata` commands to load the specified fixtures for all applications.
 
-That may sound dangerous, but that's what you want when you ask to
-restore the factory settings of a Django application.
-
-Django's `reset` command may fail after an upgrade if the new Lino
-version defines new tables. In that case, flush sends a DROP TABLE
-which fails because that table doesn't exist.
+This may sound dangerous, but it is what you want when you ask to
+restore the factory settings of a Lino application.
 
 This reimplements a simplified version of Django's `reset` command,
-without the possibility of deleting only *some* data (the thing which
-caused so big problems that Django 1.3. decided to `deprecate this command
-<https://docs.djangoproject.com/en/dev/releases/1.3\
+without the possibility of deleting *only some* data (the thing which
+caused so big problems that Django 1.3. decided to `deprecate this
+command <https://docs.djangoproject.com/en/dev/releases/1.3\
 /#reset-and-sqlreset-management-commands>`__.
 
+Truncating the database (i.e. dropping all tables without dropping the
+database itself) is not always trivial, and Lino's :manage:`initdb`
+sometimes fails on this task.  For example when the dbms is severe
+when checking foreign key integrity.
+
+TODO: Django now has a `flush
+<https://docs.djangoproject.com/en/dev/ref/django-admin/#flush>`_
+command which is hopefully the part of "reset" which we are
+reimplimenting here. Ticket :ticket:`48`.
+
 """
 
 from __future__ import unicode_literals
@@ -34,6 +38,7 @@ from optparse import make_option
 from django.conf import settings
 from django.core.management import call_command
 from django.core.management.base import BaseCommand, CommandError
+from django.db.utils import IntegrityError, OperationalError
 
 from django.core.management.sql import sql_delete, sql_flush
 from django.core.management.color import no_style
@@ -52,6 +57,10 @@ USE_DROP_CREATE = False  # tried, but doesn't seem to work
 """
 http://stackoverflow.com/questions/3414247/django-drop-all-tables-from-database
 http://thingsilearned.com/2009/05/10/drop-database-command-for-django-manager/
+
+The problem is that it accepts the DROP DATABASE, but afterwards I get
+"no database selected" when I run syncdb.
+
 """
 
 
@@ -72,6 +81,24 @@ class Command(BaseCommand):
             'Defaults to the "default" database.'),
     )
 
+    def try_sql(self, cursor, sql_list):
+        hope = False
+        pending = []
+        errors = []
+        for sql in sql_list:
+            try:
+                cursor.execute(sql)
+                hope = True
+            except IntegrityError as e:
+                pending.append(sql)
+                errors.append(str(e))
+        if not hope:
+            msg = "%d pending SQL statements failed:" % len(pending)
+            for i, sql in enumerate(pending):
+                msg += "\n%s (%s)" % (sql, errors[i])
+            raise Exception(msg)
+        return pending
+
     def handle(self, *args, **options):
 
         #~ from lino.core.kernel import analyze_models
@@ -85,6 +112,7 @@ class Command(BaseCommand):
         #~ dblogger.info("FIXTURE_DIRS is %s",settings.FIXTURE_DIRS)
         using = options.get('database', DEFAULT_DB_ALIAS)
         dbname = settings.DATABASES[using]['NAME']
+        engine = settings.DATABASES[using]['ENGINE']
         if options.get('interactive'):
             if not confirm("""We are going to flush your database (%s).
 Are you sure (y/n) ?""" % dbname):
@@ -93,14 +121,12 @@ Are you sure (y/n) ?""" % dbname):
         options.update(interactive=False)
         #~ dblogger.info("Lino initdb %s started on database %s.", args, dbname)
 
-        if USE_DROP_CREATE:
-
+        if USE_DROP_CREATE and engine == 'django.db.backends.mysql':
+            # TODO: this works only for mysql
             from django.db import connection
             cursor = connection.cursor()
-            #~ cursor.execute("DROP DATABASE %s;", [connection.settings_dict['NAME']])
-            #~ cursor.execute("CREATE DATABASE %s;", [connection.settings_dict['NAME']])
             cursor.execute("DROP DATABASE %s;" % dbname)
-            cursor.execute("CREATE DATABASE %s;" % dbname)
+            cursor.execute("CREATE DATABASE %s charset 'utf8';" % dbname)
 
         else:
 
@@ -129,14 +155,18 @@ Are you sure (y/n) ?""" % dbname):
 
             #~ print sql_list
 
-            try:
-                cursor = conn.cursor()
-                for sql in sql_list:
-                    # print sql
-                    cursor.execute(sql)
-            except Exception:
-                transaction.rollback_unless_managed(using=using)
-                raise
+            if len(sql_list):
+                try:
+                    cursor = conn.cursor()
+                    conn.disable_constraint_checking()
+                    pending = self.try_sql(cursor, sql_list)
+                    while len(pending):
+                        pending = self.try_sql(cursor, pending)
+                    conn.enable_constraint_checking()
+
+                except Exception:
+                    transaction.rollback_unless_managed(using=using)
+                    raise
 
             transaction.commit_unless_managed()
 
