@@ -1,49 +1,47 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2012-2013 Luc Saffre
-## This file is part of the Lino project.
-## Lino is free software; you can redistribute it and/or modify 
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or
-## (at your option) any later version.
-## Lino is distributed in the hope that it will be useful, 
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the 
-## GNU General Public License for more details.
-## You should have received a copy of the GNU General Public License
-## along with Lino; if not, see <http://www.gnu.org/licenses/>.
+# Copyright 2012-2013 Luc Saffre
+# License: BSD (see file COPYING for details)
 
-r"""
-This module is a Python implementation of the basic truths of accounting.
+r"""This module is a Python implementation of some basic truths of
+accounting.
 
-It has a hard-coded list of "account types", 
-including the "top-level accounts".
+This module is part of the Lino test suite. You can test only this
+module by issuing::
 
-It has a hard-coded list of the Sheets
+  $ python setup.py test -s tests.UtilsTests.test_accounts_utils
+
+It has a hard-coded list of `account types`_, including the "top-level
+accounts".
+
+It has a hard-coded list of the Sheets used in annual accounting
+reports.
 
 Debit and Credit
 ----------------
 
-An accounting transaction is either Debit or Credit.
-We represent this internally as a boolean, but define two names DEBIT and CREDIT:
+An accounting transaction is either Debit or Credit.  We represent
+this internally as a boolean, but define two names `DEBIT` and
+`CREDIT`:
 
 >>> DEBIT
 True
 >>> CREDIT
 False
 
+Account types
+-------------
 
 Accounting Equation:
 
   Assets = Liabilities + Capital
  
-Expanded accounting equation: 
+Expanded accounting equation:
 
     Assets + Expenses = Liabilities + Equity + Revenue
     
-Accounts on the left side of the equation (Assets and Expenses) 
-are normally DEBITed and have DEBIT balances. 
-
-That's what the :attr:`dc <AccountType.dc>` attribute means.
+Accounts on the left side of the equation (Assets and Expenses) are
+normally DEBITed and have DEBIT balances.  That's what the :attr:`dc
+<AccountType.dc>` attribute means:
 
 
 >>> print unicode(DCLABELS[AccountTypes.assets.dc])
@@ -54,9 +52,9 @@ Debit
 >>> print isinstance(AccountTypes.bank_accounts,Assets)
 True
 
-  
-`Wikipedia <http://en.wikipedia.org/wiki/Debits_and_credits>`_ gives a 
-Summary table of standard increasing and decreasing attributes for the 
+
+`Wikipedia <http://en.wikipedia.org/wiki/Debits_and_credits>`_ gives a
+Summary table of standard increasing and decreasing attributes for the
 five accounting elements:
 
 ============= ===== ======
@@ -71,7 +69,8 @@ Equity        \−     \+
   
 The equivalent in Python is:
 
->>> for t in AccountTypes.filter(top_level=True): #doctest: +NORMALIZE_WHITESPACE
+>>> for t in AccountTypes.filter(top_level=True):
+... #doctest: +NORMALIZE_WHITESPACE
 ...     print "%-12s|%-15s|%-6s" % (t.name, unicode(t), DCLABELS[t.dc])
 assets      |Assets         |Debit
 liabilities |Liabilities    |Credit
@@ -130,6 +129,25 @@ Income and Expenses are listed in the Profit & Loss statement.
 []
 
 
+As a summary here once more this hard-coded table of basic account
+types:
+
+>>> from lino import rt
+>>> rt.show('accounts.AccountTypes')
+==================== =============== =============== ======== ==========
+ value                name            text            D/C      Sheet
+-------------------- --------------- --------------- -------- ----------
+ A                    assets          Assets          Debit    Balance
+ L                    liabilities     Liabilities     Credit   Balance
+ I                    incomes         Incomes         Credit   Earnings
+ E                    expenses        Expenses        Debit    Earnings
+ C                    capital         Capital         Credit   Balance
+ B                    bank_accounts   Bank accounts   Debit    Balance
+ **Total (6 rows)**                                   **3**
+==================== =============== =============== ======== ==========
+<BLANKLINE>
+
+
 
 TODO
 ----
@@ -194,26 +212,61 @@ from lino import dd
 DEBIT = True
 CREDIT = False
 
-DCLABELS = { 
-  DEBIT: _("Debit"), 
-  CREDIT: _("Credit") 
+DCLABELS = {
+    DEBIT: _("Debit"),
+    CREDIT: _("Credit")
 }
 
 
+from lino.ui.store import BooleanStoreField
+from django.db import models
+
+
+class DebitOrCreditStoreField(BooleanStoreField):
+
+    """
+    This is used as `lino_atomizer_class` for :class:`DebitOrCreditField`.
+    """
+
+    def format_value(self, ar, v):
+        return unicode(DCLABELS[v])
+
+
+class DebitOrCreditField(models.BooleanField):
+
+    """A field that stores either :attr:`DEBIT
+    <lino.modlib.accounts.utils.DEBIT>` or :attr:`CREDIT
+    <lino.modlib.accounts.utils.CREDIT>` (see
+    :mod:`lino.modlib.accounts.utils`).
+
+    """
+    lino_atomizer_class = DebitOrCreditStoreField
+
+    def __init__(self, *args, **kw):
+        kw.setdefault('help_text',
+                      _("Debit (checked) or Credit (not checked)"))
+        kw.setdefault('default', None)
+        models.BooleanField.__init__(self, *args, **kw)
+
+
 class Sheet(object):
+
     """
     Base class for a financial statement.
     """
-    verbose_name = _("Financial statement") # Comptes annuels    Jahresabschluss               Jaarverslag              Aastaaruanne  
-    
+    # Comptes annuels Jahresabschluss Jaarverslag  Aastaaruanne
+    verbose_name = _("Financial statement")
+
     @classmethod
     def account_types(cls):
         """
         Return a list the top-level account types included in this Sheet
         """
         return [o for o in AccountTypes.objects() if o.sheet == cls and o.top_level]
-        
-class Balance(Sheet): 
+
+
+class Balance(Sheet):
+
     """
     In financial accounting, a 
     balance sheet or 
@@ -238,23 +291,31 @@ class Balance(Sheet):
     https://en.wikipedia.org/wiki/Balance_sheet
     
     """
-    verbose_name = _("Balance sheet") #  Bilan              Bilanz                        Balans                   Bilanss       
-    
+    verbose_name = _("Balance sheet")  # Bilan  Bilanz  Balans  Bilanss
+
 
 #~ class ProfitOrLoss(Sheet):
-class Earnings(Sheet): 
+class Earnings(Sheet):
+
     """
     https://en.wikipedia.org/wiki/Statement_of_comprehensive_income#Requirements_of_IFRS
     """
-    verbose_name = _("Profit & Loss statement") #  Compte de résultat Gewinn- und Verlustrechnung   Winst-en-verliesrekening ...           
+    # Compte de résultat Gewinn- und Verlustrechnung
+    # Winst-en-verliesrekening ...
+    verbose_name = _("Profit & Loss statement")
+
 
 class CashFlow(Sheet):
-    verbose_name = _("Cash flow statement") #  
-    
-    
-Sheet.objects = (Balance,Earnings,CashFlow)
+    verbose_name = _("Cash flow statement")
 
-    
+# La balance des comptes (généraux|particuliers|fournisseurs|clients)
+
+
+class AccountsBalance(Sheet):
+    verbose_name = _("Cash flow statement")
+
+
+Sheet.objects = (Balance, Earnings, CashFlow)
 
 
 class AccountType(dd.Choice):
@@ -263,62 +324,76 @@ class AccountType(dd.Choice):
     #~ def __init__(self,value,text,name,dc=True,**kw):
         #~ self.dc = dc
         #~ super(AccountType,self).__init__(value,text,name)
+
     def __init__(self):
         pass
         #~ self.dc = dc
         #~ super(AccountType,self).__init__(value,text,name)
-        
+
+
 class Assets(AccountType):
     value = 'A'
     text = _("Assets")   # Aktiva, Anleihe, Vermögen, Anlage
-    name  = "assets"
+    name = "assets"
     dc = DEBIT
     sheet = Balance
 
+
 class Liabilities(AccountType):
     value = 'L'
-    text = _("Liabilities") # Guthaben, Schulden, Verbindlichkeit  
-    name  = "liabilities"
+    text = _("Liabilities")  # Guthaben, Schulden, Verbindlichkeit
+    name = "liabilities"
     dc = CREDIT
     sheet = Balance
 
-class Capital(AccountType): # aka Owner's Equities
-    value = 'C' 
-    text = _("Capital") # Kapital 
+
+class Capital(AccountType):  # aka Owner's Equities
+    value = 'C'
+    text = _("Capital")  # Kapital
     name = "capital"
     dc = CREDIT
     sheet = Balance
 
+
 class Income(AccountType):
     value = 'I'
-    text = _("Incomes") # Gain/Revenue     Einnahmen  Produits
-    name  = "incomes" 
+    text = _("Incomes")  # Gain/Revenue     Einnahmen  Produits
+    name = "incomes"
     dc = CREDIT
     balance_sheet = True
     sheet = Earnings
 
+
 class Expenses(AccountType):
-    value = 'E' 
-    text = _("Expenses") # Loss/Cost       Ausgaben   Charges
+    value = 'E'
+    text = _("Expenses")  # Loss/Cost       Ausgaben   Charges
     name = "expenses"
     dc = DEBIT
     sheet = Earnings
 
+
 class BankAccounts(Assets):
     top_level = False
     value = 'B'
     text = _("Bank accounts")
     name = 'bank_accounts'
-    #~ dc = CREDIT    
-    
-    
-    
-    
+    #~ dc = CREDIT
+
+
 class AccountTypes(dd.ChoiceList):
     verbose_name = _("Account Type")
     item_class = AccountType
-    
-    
+    column_names = 'value name text dc sheet'
+
+    @dd.virtualfield(DebitOrCreditField(_("D/C")))
+    def dc(cls, choice, ar):
+        return choice.dc
+
+    @dd.virtualfield(models.CharField(_("Sheet"), max_length=20))
+    def sheet(cls, choice, ar):
+        return choice.sheet.__name__
+
+
 add = AccountTypes.add_item
 #~ def add(*args):
     #~ AccountTypes.add_item_instance(AccountType(*args))
@@ -331,11 +406,9 @@ add(Capital())
 add(BankAccounts())
 
 
-
 def _test():
     import doctest
     doctest.testmod()
 
 if __name__ == "__main__":
     _test()
-
