@@ -16,6 +16,7 @@ from django.conf import settings
 
 from lino import dd, rt, mixins
 from django.utils.translation import ugettext_lazy as _
+from lino.utils.report import Report
 from lino.modlib.ledger.utils import FiscalYears
 from lino.utils.xmlgen.html import E
 from lino.utils import join_elems
@@ -445,9 +446,9 @@ class Vouchers(dd.Table):
 
 #~ class VouchersByJournal(dd.Table):
 class ByJournal(dd.Table):
-    order_by = ["number"]
+    order_by = ["-number"]
     master_key = 'journal'  # see django issue 10808
-    start_at_bottom = True
+    # start_at_bottom = True
 
     @classmethod
     def get_title_base(self, ar):
@@ -460,7 +461,7 @@ class ByJournal(dd.Table):
 
 class VouchersByPartner(dd.VirtualTable):
     label = _("VAT vouchers")
-    order_by = ["-date"]
+    order_by = ["-date", '-id']
     master = 'contacts.Partner'
     column_names = "date voucher total_incl total_base total_vat"
 
@@ -632,7 +633,7 @@ class Movements(dd.Table):
         ppartner=models.ForeignKey(partner_model, blank=True, null=True),
         paccount=models.ForeignKey('accounts.Account', blank=True, null=True),
         pjournal=JournalRef(blank=True),
-        cleared=mixins.YesNo.field(_("Show cleared movements"), blank=True))
+        cleared=dd.YesNo.field(_("Show cleared movements"), blank=True))
     params_layout = """
     start_date end_date cleared
     pjournal pyear ppartner paccount"""
@@ -641,9 +642,9 @@ class Movements(dd.Table):
     def get_request_queryset(cls, ar):
         qs = super(Movements, cls).get_request_queryset(ar)
 
-        if ar.param_values.cleared == mixins.YesNo.yes:
+        if ar.param_values.cleared == dd.YesNo.yes:
             qs = qs.filter(satisfied=True)
-        elif ar.param_values.cleared == mixins.YesNo.no:
+        elif ar.param_values.cleared == dd.YesNo.no:
             qs = qs.filter(satisfied=False)
 
         if ar.param_values.ppartner:
@@ -673,7 +674,7 @@ class MovementsByPartner(Movements):
     @classmethod
     def param_defaults(cls, ar, **kw):
         kw = super(MovementsByPartner, cls).param_defaults(ar, **kw)
-        kw.update(cleared=mixins.YesNo.no)
+        kw.update(cleared=dd.YesNo.no)
         kw.update(pyear='')
         return kw
 
@@ -689,7 +690,7 @@ class MovementsByAccount(Movements):
     def param_defaults(cls, ar, **kw):
         kw = super(MovementsByAccount, cls).param_defaults(ar, **kw)
         if ar.master_instance is not None and ar.master_instance.clearable:
-            kw.update(cleared=mixins.YesNo.no)
+            kw.update(cleared=dd.YesNo.no)
             kw.update(pyear='')
         return kw
 
@@ -983,7 +984,7 @@ class InvoiceDetail(dd.FormLayout):
 
 class Invoices(dd.Table):
     model = 'ledger.AccountInvoice'
-    order_by = ["date", "id"]
+    order_by = ["-id"]
     column_names = "date id number partner total_incl user *"
     parameters = dict(
         pyear=FiscalYears.field(blank=True),
@@ -995,7 +996,7 @@ class Invoices(dd.Table):
     journal partner
     date total_incl
     """
-    start_at_bottom = True
+    # start_at_bottom = True
 
     @classmethod
     def get_request_queryset(cls, ar):
@@ -1285,7 +1286,7 @@ class Creditors(DebtorsCreditors):
 ##
 
 
-class Situation(mixins.Report):
+class Situation(Report):
     label = _("Situation")
     help_text = _("Overview of the financial situation on a given date.")
     required = dd.required(user_groups='accounts')
@@ -1295,7 +1296,7 @@ class Situation(mixins.Report):
     report_items = (Debtors, Creditors)
 
 
-class ActivityReport(mixins.Report):
+class ActivityReport(Report):
     label = _("Activity Report")
     help_text = _("Overview of the financial activity during a given period.")
     required = dd.required(user_groups='accounts')
