@@ -1,7 +1,13 @@
 # Copyright 2012-2014 Luc Saffre
 # License: BSD (see file COPYING for details)
 
-"""See :mod:`ml.vat`."""
+"""The :xfile:`models.py` module for :mod:`lino.modlib.vat`.
+
+It defines two database models :class:`VatRate` and
+:class:`PaymentTerm`, and a series of mixins which are used in
+:mod:`lino.modlib.ledger`, :mod:`lino.modlib.sales` and other apps.
+
+"""
 
 from __future__ import unicode_literals
 from __future__ import print_function
@@ -17,9 +23,14 @@ from dateutil.relativedelta import relativedelta
 from django.db import models
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
+from django.db.models import Q
+
+from lino.mixins.periods import DatePeriod
+from lino.mixins import Sequenced
+from lino.mixins import BabelNamed
+from lino.modlib.system.mixins import PeriodEvents
 
 from lino import dd, rt
-from lino import mixins
 
 config = dd.plugins.vat
 
@@ -39,7 +50,19 @@ ZERO = Decimal('0.00')
 
 
 class VatClasses(dd.ChoiceList):
+    """
+    A VAT class is a direct or indirect property of a trade object
+    (e.g. a Product) which determines the VAT *rate* to be used.  It
+    does not contain the actual rate because this still varies
+    depending on your country, the time and type of the operation, and
+    possibly other factors.
 
+    Typical content is as follows (but applications may redefine or
+    extend this list in :meth:`ad.Site.setup_choicelists`):
+
+    .. django2rst:: rt.show("vat.VatRegimes")
+
+    """
     verbose_name = _("VAT Class")
 add = VatClasses.add_item
 add('0', _("Exempt"), 'exempt')    # post stamps, ...
@@ -48,11 +71,23 @@ add('2', _("Normal"), 'normal')    # everything else
 
 
 class VatRegime(dd.Choice):
+    "Base class for choices of :class:`VatRegimes`."
 
     item_vat = True
+    "Whether unit prices are VAT included or not."
 
 
 class VatRegimes(dd.ChoiceList):
+    """
+    The VAT regime is a classification of the way how VAT is being
+    handled, e.g. whether and how it is to be paid.
+
+    Typical content is as follows (but applications may redefine or
+    extend this list in :meth:`lino.core.site_def.Site.setup_choicelists`):
+
+    .. django2rst:: rt.show("vat.VatClasses")
+
+    """
     verbose_name = _("VAT Regime")
     item_class = VatRegime
     help_text = _(
@@ -69,8 +104,9 @@ add('50', _("Exempt"), 'exempt', item_vat=False)
 
 
 class TradeType(dd.Choice):
-
     """
+    Base class for the choices of :class:`TradeTypes`.
+    
     """
     price_field_name = None
     price_field_label = None
@@ -83,6 +119,10 @@ class TradeType(dd.Choice):
     dc = accounts.DEBIT
 
     def get_base_account(self):
+        """Return the :class:`ml.accounts.Account` into which the **base
+        amount** of any operation should be booked.
+
+        """
         if self.base_account_field_name is None:
             return None
             # raise Exception("%s has no base_account_field_name!" % self)
@@ -90,28 +130,55 @@ class TradeType(dd.Choice):
                        self.base_account_field_name)
 
     def get_vat_account(self):
+        """Return the :class:`ml.accounts.Account` into which the **VAT
+        amount** of any operation should be booked.
+
+        """
         if self.vat_account_field_name is None:
             return None
             # raise Exception("%s has no vat_account_field_name!" % self)
         return getattr(settings.SITE.site_config, self.vat_account_field_name)
 
     def get_partner_account(self):
+        """Return the :class:`ml.accounts.Account` into which the **total
+      amount** of any operation (base + VAT) should be booked.
+
+        """
         if self.partner_account_field_name is None:
             return None
         return getattr(
             settings.SITE.site_config, self.partner_account_field_name)
 
     def get_product_base_account(self, product):
+        """Return the :class:`ml.accounts.Account` into which the **base
+        amount** of any operation should be booked.
+
+        """
         if self.base_account_field_name is None:
             raise Exception("%s has no base_account_field_name" % self)
         return getattr(product, self.base_account_field_name) or \
             getattr(settings.SITE.site_config, self.base_account_field_name)
 
     def get_catalog_price(self, product):
+        """Return the catalog price of the given product for operations with
+this trade type.
+
+        """
         return getattr(product, self.price_field_name)
 
 
 class TradeTypes(dd.ChoiceList):
+    """The **trade type** is one of the basic properties of every
+operation.
+
+    Typical content is as follows (but applications may redefine or
+    extend this list in :meth:`ad.Site.setup_choicelists`):
+
+       .. django2rst:: rt.show("vat.TradeTypes")
+
+    """
+
+
     verbose_name = _("Trade Type")
     item_class = TradeType
     help_text = _("The type of trade: usually either `sales` or `purchases`.")
@@ -142,31 +209,81 @@ def inject_vat_fields(sender, **kw):
                     blank=True, null=True))
         if tt.vat_account_field_name is not None:
             dd.inject_field('system.SiteConfig', tt.vat_account_field_name,
-                            dd.ForeignKey('accounts.Account',
-                                          verbose_name=tt.vat_account_field_label,
-                                          related_name='configs_by_' +
-                                          tt.vat_account_field_name,
-                                          blank=True, null=True))
+                            dd.ForeignKey(
+                                'accounts.Account',
+                                verbose_name=tt.vat_account_field_label,
+                                related_name='configs_by_' +
+                                tt.vat_account_field_name,
+                                blank=True, null=True))
         if tt.base_account_field_name is not None:
             dd.inject_field('system.SiteConfig', tt.base_account_field_name,
-                            dd.ForeignKey('accounts.Account',
-                                          verbose_name=tt.base_account_field_label,
-                                          related_name='configs_by_' +
-                                          tt.base_account_field_name,
-                                          blank=True, null=True))
+                            dd.ForeignKey(
+                                'accounts.Account',
+                                verbose_name=tt.base_account_field_label,
+                                related_name='configs_by_' +
+                                tt.base_account_field_name,
+                                blank=True, null=True))
             dd.inject_field('products.Product', tt.base_account_field_name,
-                            dd.ForeignKey('accounts.Account',
-                                          verbose_name=tt.base_account_field_label,
-                                          related_name='products_by_' +
-                                          tt.base_account_field_name,
-                                          blank=True, null=True))
+                            dd.ForeignKey(
+                                'accounts.Account',
+                                verbose_name=tt.base_account_field_label,
+                                related_name='products_by_' +
+                                tt.base_account_field_name,
+                                blank=True, null=True))
         if tt.price_field_name is not None:
             dd.inject_field('products.Product', tt.price_field_name,
                             dd.PriceField(verbose_name=tt.price_field_label,
                                           blank=True, null=True))
 
 
-class PaymentTerm(mixins.BabelNamed):
+class VatRate(Sequenced, DatePeriod):
+    """The demo database comes with the following VAT rate definitions
+    (defined in :mod:`lino.modlib.vat.fixtures.euvatrates`):
+
+    .. django2rst:: rt.show("vat.VatRates")
+
+    """
+    class Meta:
+        verbose_name = _("VAT rate")
+        verbose_name_plural = _("VAT rates")
+
+    trade_type = TradeTypes.field(blank=True)
+    vat_class = VatClasses.field(blank=True)
+    vat_regime = VatRegimes.field(blank=True)
+    rate = models.DecimalField(default=ZERO, decimal_places=4, max_digits=7)
+    country = dd.ForeignKey('countries.Country', blank=True, null=True)
+
+    @classmethod
+    def find_vat_rate(cls, trade_type, vat_regime, vat_class, country, date):
+        qs = cls.objects.order_by('seqno')
+        qs = qs.filter(Q(country__isnull=True) | Q(country=country))
+        if vat_class is not None:
+            qs = qs.filter(Q(vat_class__isnull=True) | Q(vat_class=vat_class))
+        if vat_regime is not None:
+            qs = qs.filter(
+                Q(vat_regime__isnull=True) | Q(vat_regime=vat_regime))
+        if trade_type is not None:
+            qs = qs.filter(
+                Q(trade_type__isnull=True) | Q(trade_type=trade_type))
+        qs = PeriodEvents.active.add_filter(qs, date)
+        if qs.count() == 0:
+            return ZERO
+            # p = dict(vat_regime=vat_regime, vat_class=vat_class,
+            #          country=country, date=date)
+            # raise Warning(_("No TAX rate configured for %s.)" % p)
+        return qs[0].rate
+
+
+class VatRates(dd.Table):
+    model = 'vat.VatRate'
+    column_names = "seqno vat_class country trade_type vat_regime rate *"
+    hide_sums = True
+
+
+class PaymentTerm(BabelNamed):
+    """A convention on how an invoice should be paid.
+
+    """
 
     class Meta:
         verbose_name = _("Payment Term")
@@ -193,7 +310,29 @@ class PaymentTerms(dd.Table):
 
 
 class VatTotal(dd.Model):
+    """
+    Model mixin which defines the fields `total_incl`, `total_base`
+    and `total_vat`.  Used for both the document header
+    (:class:`VatDocument`) and for each item (:class:`VatItemBase`).
 
+    .. attribute:: total_incl
+    
+    A :class:`dd.PriceField` which stores the total amount VAT
+    *included*.
+
+    .. attribute:: total_base
+
+    A :class:`dd.PriceField` which stores the total amount VAT
+    *excluded*.
+
+    .. attribute:: total_vat
+
+    A :class:`dd.PriceField` which stores the amount of VAT.
+
+
+
+
+    """
     class Meta:
         abstract = True
 
@@ -207,6 +346,10 @@ class VatTotal(dd.Model):
     # when `auto_compute_totals` is True.
 
     auto_compute_totals = False
+    """Set this to `True` on subclasses who compute their totals
+    automatically.
+
+    """
 
     def disabled_fields(self, ar):
         fields = super(VatTotal, self).disabled_fields(ar)
@@ -218,7 +361,7 @@ class VatTotal(dd.Model):
         pass
 
     def get_vat_rate(self, *args, **kw):
-        return None
+        return ZERO
 
     def total_base_changed(self, ar):
         #~ logger.info("20121204 total_base_changed %r",self.total_base)
@@ -229,8 +372,6 @@ class VatTotal(dd.Model):
         #~ assert not isinstance(self.total_base,basestring)
         rate = self.get_vat_rate()
         #~ logger.info("20121206 total_base_changed %s",rate)
-        if rate is None:
-            return
         self.total_vat = self.total_base * rate
         self.total_incl = self.total_base + self.total_vat
 
@@ -241,8 +382,6 @@ class VatTotal(dd.Model):
                 return
         #~ assert not isinstance(self.total_vat,basestring)
         rate = self.get_vat_rate()
-        if rate is None:
-            return
         self.total_base = self.total_vat * rate
         self.total_incl = self.total_base + self.total_vat
 
@@ -254,8 +393,6 @@ class VatTotal(dd.Model):
         #~ assert not isinstance(self.total_incl,basestring)
         rate = self.get_vat_rate()
         #~ logger.info("20121206 total_incl_changed %s",rate)
-        if rate is None:
-            return
         self.total_base = self.total_incl / (1 + rate)
         self.total_vat = self.total_incl - self.total_base
 
@@ -378,7 +515,8 @@ class VatDocument(VatTotal):
         super(VatDocument, self).before_state_change(ar, old, new)
 
 
-class VatItemBase(mixins.Sequenced, VatTotal):
+class VatItemBase(Sequenced, VatTotal):
+    "Model mixin for items of a :class:`VatTotal`."
 
     class Meta:
         abstract = True
@@ -387,7 +525,7 @@ class VatItemBase(mixins.Sequenced, VatTotal):
     vat_class = VatClasses.field(blank=True, default=get_default_vat_class)
 
     def get_vat_class(self, tt):
-        name = settings.SITE.plugins.vat.get_vat_class(tt, self)
+        name = dd.plugins.vat.get_vat_class(tt, self)
         return VatClasses.get_by_name(name)
 
     def vat_class_changed(self, ar):
@@ -410,8 +548,10 @@ class VatItemBase(mixins.Sequenced, VatTotal):
         tt = self.voucher.get_trade_type()
         if self.vat_class is None:
             self.vat_class = self.get_vat_class(tt)
-        return settings.SITE.plugins.vat.get_vat_rate(
-            tt, self.vat_class, self.voucher.vat_regime)
+        # return settings.SITE.plugins.vat.get_vat_rate(
+        return VatRate.find_vat_rate(
+            tt, self.voucher.vat_regime, self.vat_class,
+            self.voucher.partner.country, self.voucher.date)
 
     #~ def save(self,*args,**kw):
         #~ super(VatItemBase,self).save(*args,**kw)
@@ -431,7 +571,6 @@ class VatItemBase(mixins.Sequenced, VatTotal):
             self.total_incl = self.total_base + self.total_vat
 
     def reset_totals(self, ar):
-        #~ logger.info("20121204 reset_totals")
         if not self.voucher.auto_compute_totals:
             total = Decimal()
             for item in self.voucher.items.exclude(id=self.id):
@@ -464,6 +603,10 @@ class VatItemBase(mixins.Sequenced, VatTotal):
 
 
 class QtyVatItemBase(VatItemBase):
+    """Model mixin for items of a :class:`VatTotal`, adds `unit_price` and
+`qty`.
+
+    """
 
     class Meta:
         abstract = True
@@ -535,7 +678,8 @@ dd.inject_field(
 
 def setup_config_menu(site, ui, profile, m):
     m = m.add_menu("vat", config.verbose_name)
-    m.add_action(PaymentTerms)
+    m.add_action('vat.PaymentTerms')
+    m.add_action('vat.VatRates')
 
 
 def setup_explorer_menu(site, ui, profile, m):
