@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 """
-This is a Python dump created using Lino 1.6.15, Django 1.6.7, Python 2.7.4, Babel 1.3, Jinja 2.7.2, Sphinx 1.3a0, python-dateutil 2.1, OdfPy ODFPY/0.9.6, docutils 0.11, suds 0.4, PyYaml 3.10, Appy 0.9.0 (2014/06/23 22:15).
+This is a Python dump created using Lino 1.6.17, Django 1.6.7, Python 2.7.4, Babel 1.3, Jinja 2.7.2, Sphinx 1.3a0, python-dateutil 2.1, OdfPy ODFPY/0.9.6, docutils 0.11, suds 0.4, PyYaml 3.10, Appy 0.9.0 (2014/06/23 22:15).
 
 """
 from __future__ import unicode_literals
@@ -109,6 +109,7 @@ uploads_UploadType = resolve_model("uploads.UploadType")
 users_Authority = resolve_model("users.Authority")
 users_User = resolve_model("users.User")
 vat_PaymentTerm = resolve_model("vat.PaymentTerm")
+vat_VatRate = resolve_model("vat.VatRate")
 
 
 def create_accounts_chart(id, name):
@@ -272,12 +273,12 @@ def create_households_type(id, name):
     if name is not None: kw.update(bv2kw('name',name))
     return households_Type(**kw)
 
-def create_ledger_journal(id, seqno, build_method, template, name, ref, trade_type, voucher_type, force_sequence, chart_id, account_id, printed_name, dc):
+def create_ledger_journal(id, build_method, template, seqno, name, ref, trade_type, voucher_type, force_sequence, chart_id, account_id, printed_name, dc):
     kw = dict()
     kw.update(id=id)
-    kw.update(seqno=seqno)
     kw.update(build_method=build_method)
     kw.update(template=template)
+    kw.update(seqno=seqno)
     if name is not None: kw.update(bv2kw('name',name))
     kw.update(ref=ref)
     kw.update(trade_type=trade_type)
@@ -295,11 +296,11 @@ def create_lists_listtype(id, name):
     if name is not None: kw.update(bv2kw('name',name))
     return lists_ListType(**kw)
 
-def create_lists_list(id, name, ref, list_type_id, remarks):
+def create_lists_list(id, ref, name, list_type_id, remarks):
     kw = dict()
     kw.update(id=id)
-    if name is not None: kw.update(bv2kw('name',name))
     kw.update(ref=ref)
+    if name is not None: kw.update(bv2kw('name',name))
     kw.update(list_type_id=list_type_id)
     kw.update(remarks=remarks)
     return lists_List(**kw)
@@ -931,6 +932,20 @@ def create_users_authority(id, user_id, authorized_id):
     kw.update(authorized_id=authorized_id)
     return users_Authority(**kw)
 
+def create_vat_vatrate(id, seqno, start_date, end_date, trade_type, vat_class, vat_regime, rate, country_id):
+    kw = dict()
+    kw.update(id=id)
+    kw.update(seqno=seqno)
+    kw.update(start_date=start_date)
+    kw.update(end_date=end_date)
+    kw.update(trade_type=trade_type)
+    kw.update(vat_class=vat_class)
+    kw.update(vat_regime=vat_regime)
+    if rate is not None: rate = Decimal(rate)
+    kw.update(rate=rate)
+    kw.update(country_id=country_id)
+    return vat_VatRate(**kw)
+
 
 
 
@@ -1017,6 +1032,7 @@ def main():
     execfile("tickets_vote.py")
     execfile("uploads_upload.py")
     execfile("users_authority.py")
+    execfile("vat_vatrate.py")
     loader.finalize()
 
 if __name__ == '__main__':
