@@ -2,11 +2,20 @@
 # Copyright 2009-2014 Luc Saffre
 # License: BSD (see file COPYING for details)
 
+#~ Note that this module may not have a docstring because any
+#~ global variable defined here will override the global
+#~ namespace of lino/__init__.py who includes it with execfile.
+
+# This module is part of the Lino test suite. 
+# To test only this module:
+#
+#   $ python setup.py test -s tests.PackagesTests
+
 from __future__ import unicode_literals
 
 SETUP_INFO = dict(
     name='lino',
-    version='1.6.15',  # not yet released
+    version='1.6.16',
     install_requires=[
         'django<1.7', 'Sphinx',
         'atelier', 'unipath', 'python_dateutil',
@@ -24,6 +33,7 @@ SETUP_INFO = dict(
     license='BSD License',
     include_package_data=True,
     zip_safe=False,
+    obsoletes=['djangosite', 'north'],
     author='Luc Saffre',
     author_email='luc.saffre@gmail.com',
     url="http://www.lino-framework.org",
@@ -143,6 +153,7 @@ lino.modlib.polls.fixtures
 lino.modlib.postings
 lino.modlib.accounts
 lino.modlib.vat
+lino.modlib.vat.fixtures
 lino.modlib.households
 lino.modlib.households.fixtures
 lino.modlib.courses
