@@ -15,7 +15,7 @@ This is a tested document. To test it, run::
 .. toctree::
 
 .. autosummary::
-   :toctree: _api
+   :toctree:
 
     addressable
     ajax
@@ -27,10 +27,12 @@ This is a tested document. To test it, run::
     dataserializer
     dbfreader
     dblogger
+    dpy
     editing
     html2odf
     html2text
     html2xhtml
+    mytidylib
     htmlgen
     instantiator
     jscompressor
