@@ -5,7 +5,14 @@
 # Copyright (c) 1999-2004 by Fredrik Lundh
 # --------------------------------------------------------------------
 
-u"""
+# This document is part of the Lino test suite. To test only this
+# document, run::
+#
+#   $ python setup.py test -s tests.UtilsTests.test_xmlgen_html
+
+
+
+"""
 A set of HTML generator tags for building HTML documents.
 
 Usage::
@@ -13,7 +20,7 @@ Usage::
     >>> from lino.utils.xmlgen.html import E
     >>> html = E.html(
     ...            E.head( E.title("Hello World") ),
-    ...            E.body( 
+    ...            E.body(
     ...              E.h1("Hello World !"),
     ...              class_="main"
     ...            )
@@ -41,24 +48,29 @@ Usage::
     
 """
 
+from __future__ import unicode_literals
+
 from xml.etree import ElementTree as ET
 from atelier import rstgen
+from lino.utils import join_elems
 from lino.utils.xmlgen import etree
-from lino.utils.xmlgen import Namespace, RAW
+from lino.utils.xmlgen import Namespace
+
 
 def HtmlNamespace(Namespace):
 
-    def tostring(self,element,*args,**kw):
-        kw.update(method='html')
-        return super(HtmlNamespace,self).tostring(element,*args,**kw)
+    def tostring(self, element, *args, **kw):
+        kw.setdefault('method', 'html')
+        return super(HtmlNamespace, self).tostring(element, *args, **kw)
 
 
 #~ E = Namespace("http://www.w3.org/1999/xhtml","""
-E = Namespace(None,"""
+E = Namespace(None, """
 a 
 abbr
 acronym
 address
+alt
 applet
 area
 b
@@ -93,9 +105,10 @@ h1
 h2     
 h3     
 h4     
-h5     
-h6     
-head   
+h5
+h6
+head
+height
 hr     
 html   
 i      
@@ -123,29 +136,29 @@ param
 pre 
 q 
 s 
-samp 
-script 
-select 
-small 
-span 
-strike 
-strong 
+samp
+script
+select
+small
+span
+strike
+strong
 style
 sub
 sup
 table
-tbody 
-td 
-textarea 
-tfoot 
-th 
-thead 
-title 
-tr 
-tt 
-u 
-ul 
-var 
+tbody
+td
+textarea
+tfoot
+th
+thead
+title
+tr
+tt
+u
+ul
+var
 
 class
 id
@@ -167,34 +180,41 @@ tabindex
 placeholder
 """)
 
-def table_header_row(*headers,**kw):
-    return E.tr(*[E.th(h,**kw) for h in headers])
-def table_body_row(*cells,**kw):
-    return E.tr(*[E.td(h,**kw) for h in cells])
-      
+
+def table_header_row(*headers, **kw):
+    return E.tr(*[E.th(h, **kw) for h in headers])
+
+
+def table_body_row(*cells, **kw):
+    return E.tr(*[E.td(h, **kw) for h in cells])
+
+
 class Table(object):
+
     def __init__(self):
         self.clear()
-        
+
     def clear(self):
         self.head = []
         self.foot = []
         self.body = []
         self.attrib = dict()
-        
-    def add_header_row(self,*args,**kw):
-        e = table_header_row(*args,**kw)
+
+    def add_header_row(self, *args, **kw):
+        e = table_header_row(*args, **kw)
         self.head.append(e)
         return e
-    def add_footer_row(self,*args,**kw):
-        e = table_body_row(*args,**kw)
+
+    def add_footer_row(self, *args, **kw):
+        e = table_body_row(*args, **kw)
         self.foot.append(e)
         return e
-    def add_body_row(self,*args,**kw):
-        e = table_body_row(*args,**kw)
+
+    def add_body_row(self, *args, **kw):
+        e = table_body_row(*args, **kw)
         self.body.append(e)
         return e
-        
+
     def as_element(self):
         children = []
         if self.head:
@@ -203,53 +223,49 @@ class Table(object):
             children.append(E.tfoot(*self.foot))
         if self.body:
             children.append(E.tbody(*self.body))
-        return E.table(*children,**self.attrib)
-      
-                  
+        return E.table(*children, **self.attrib)
 
 
 class Document(object):
-    def __init__(self,title,stylesheets=None):
+
+    def __init__(self, title, stylesheets=None):
         self.title = title
         self.body = []
         self.stylesheets = stylesheets or []
-        
-    def add_stylesheet(self,url):
+
+    def add_stylesheet(self, url):
         self.stylesheets.append(url)
-        
+
     def add_table(self):
         t = Table()
         self.body.append(t)
         return t
-        
-    def write(self,*args,**kw):
-        ET.ElementTree(self.as_element()).write(*args,**kw)
-        
+
+    def write(self, *args, **kw):
+        ET.ElementTree(self.as_element()).write(*args, **kw)
+
     def as_element(self):
         body = []
         for e in self.body:
-            if isinstance(e,Table):
+            if isinstance(e, Table):
                 body.append(e.as_element())
             else:
                 body.append(e)
         headers = []
         for css in self.stylesheets:
-            headers.append(E.link(rel="stylesheet",type="text/css",href=css))
+            headers.append(E.link(rel="stylesheet", type="text/css", href=css))
         headers.append(E.title(self.title))
 
         return E.html(
-          E.head(*headers),
-          E.body(*body)
-          )
+            E.head(*headers),
+            E.body(*body)
+        )
 
 
-
-
-
-def _html2rst(e,**kw):
+def _html2rst(e, **kw):
     #~ print "20120613 html2odftext()", e.tag, e.text
     rst = ''
-    if e.tag in ('p','li'): 
+    if e.tag in ('p', 'li'):
         rst += '\n\n'
     elif e.tag == 'br':
         rst += ' |br| \n'
@@ -259,20 +275,20 @@ def _html2rst(e,**kw):
         rst += '*'
     elif e.tag == 'a':
         rst += '`'
-    
+
     #~ doesn't yet work:
     """
     """
-        
+
     #~ if e.tag == 'a':
         #~ return '`%s <%s>`__' % (e.text,e.get('href'))
-        
+
     if e.text:
         rst += e.text
     for child in e:
         rst += _html2rst(child)
-        
-    if e.tag == 'p': 
+
+    if e.tag == 'p':
         rst += '\n\n'
     elif e.tag == 'b':
         if rst == '**':
@@ -288,11 +304,12 @@ def _html2rst(e,**kw):
         rst += ' <%s>`__' % e.get('href')
     #~ else:
         #~ rst += ' '
-        
+
     if e.tail:
         rst += e.tail
     return rst
 
+
 def html2rst(e):
     """
     Convert a :mod:`lino.utils.xmlgen.html` element 
@@ -304,7 +321,7 @@ def html2rst(e):
     Usage example:
     
     >>> from lino.utils.xmlgen.html import E, html2rst
-    >>> e = E.p("This is a ",E.b("first")," test.")
+    >>> e = E.p("This is a ", E.b("first"), " test.")
     >>> print html2rst(e)
     This is a **first** test.
     
@@ -326,55 +343,72 @@ def html2rst(e):
     An empty bold text:
     """
     return _html2rst(e).strip()
-    
-
-
-
 
 
 class RstTable(rstgen.Table):
+
     """\
 A table containing elementtree HTML:
 
 .. complextable::
   :header: 
-  
+
   Code <NEXTCELL> Result <NEXTROW>
 
   >>> from lino.utils.xmlgen.html import E, RstTable
-  >>> headers = [E.p("A ",E.b("formatted")," header"),"A plain header"]
-  >>> rows = [[1,2],[3,4]]
+  >>> headers = [E.p("A ", E.b("formatted"), " header"), "A plain header"]
+  >>> rows = [[1,2], [3,4]]
   >>> print RstTable(headers).to_rst(rows)
-  ============================ ================
-   A **formatted** header       A plain header
-  ---------------------------- ----------------
-   1                            2
-   3                            4
-  ============================ ================
+  ======================== ================
+   A **formatted** header   A plain header
+  ------------------------ ----------------
+   1                        2
+   3                        4
+  ======================== ================
   <BLANKLINE>
-  
+
   <NEXTCELL>
-  
-  ============================ ================
-   A **formatted** header       A plain header
-  ---------------------------- ----------------
-   1                            2
-   3                            4
-  ============================ ================
+
+  ======================== ================
+   A **formatted** header   A plain header
+  ------------------------ ----------------
+   1                        2
+   3                        4
+  ======================== ================
 
     """
-    def convert(self,v):
-        if etree.iselement(v): 
+
+    def format_value(self, v):
+        if etree.iselement(v):
             return html2rst(v)
-        return rstgen.Table.convert(self,v)
+        return super(RstTable, self).format_value(v)
 
 
+def lines2p(lines, min_height=0, **attrs):
+    """Examples:
 
+    >>> print(E.tostring(lines2p(['first', 'second'])))
+    <p>first<br />second</p>
 
+    >>> print(E.tostring(lines2p(['first', 'second'], min_height=5)))
+    <p>first<br />second<br /><br /><br /></p>
 
+    If `min_height` is specified, and `lines` contains more items,
+    then we don't truncate:
 
+    >>> print(E.tostring(lines2p(['a', 'b', 'c', 'd', 'e'], min_height=4)))
+    <p>a<br />b<br />c<br />d<br />e</p>
 
+    This also works:
 
+    >>> print(E.tostring(lines2p([], min_height=5)))
+    <p><br /><br /><br /><br /></p>
+
+    """
+    while len(lines) < min_height:
+        lines.append('')
+    lines = join_elems(lines, E.br)
+    return E.p(*lines, **attrs)
 
 
 def _test():
@@ -383,4 +417,3 @@ def _test():
 
 if __name__ == "__main__":
     _test()
-
