@@ -69,6 +69,9 @@ class DocsTests(LinoTestCase):
     def test_polly(self):
         self.run_simple_doctests("docs/tested/polly.rst")
 
+    def test_choicelists(self):
+        self.run_simple_doctests("docs/dev/choicelists.rst")
+
     def test_presto(self):
         self.run_simple_doctests("docs/tested/test_presto.rst")
 
@@ -146,7 +149,7 @@ class UtilsTests(LinoTestCase):
     def test_memo(self):
         self.run_simple_doctests('lino/utils/memo.py')
 
-    def test_06(self):
+    def test_tidy(self):
         self.run_simple_doctests('lino/utils/html2xhtml.py')
 
     def test_demonames(self):
@@ -167,6 +170,9 @@ class UtilsTests(LinoTestCase):
     def test_jsgen(self):
         self.run_simple_doctests('lino/utils/jsgen.py')
 
+    def test_site(self):
+        self.run_simple_doctests('lino/core/site_def.py')
+
     def test_format_date(self):
         self.run_simple_doctests('lino/utils/format_date.py')
 
